==> 1.0.43.tar.gz: admmono/src/java/com/rjconsultores/ventaboletos/web/gui/controladores/catalogos/EditarPtovtaAntifraudeController.java <==
package com.rjconsultores.ventaboletos.web.gui.controladores.catalogos;

import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.Executions;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zul.Combobox;
import org.zkoss.zul.Messagebox;
import org.zkoss.zul.Textbox;

import com.rjconsultores.ventaboletos.entidad.Empresa;
import com.rjconsultores.ventaboletos.entidad.PtovtaAntifraude;
import com.rjconsultores.ventaboletos.entidad.PuntoVenta;
import com.rjconsultores.ventaboletos.service.PtovtaAntifraudeService;
import com.rjconsultores.ventaboletos.utilerias.UsuarioLogado;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;
import com.rjconsultores.ventaboletos.web.utilerias.MyListbox;

/**
 * 
 * @author wilian
 * 
 */
@Controller("editarPtovtaAntifraudeController")
@Scope("prototype")
public class EditarPtovtaAntifraudeController extends MyGenericForwardComposer {
	
	private static final long serialVersionUID = 1L;

	private static Logger log = Logger.getLogger(EditarPtovtaAntifraudeController.class);
	
	@Autowired
	private PtovtaAntifraudeService ptovtaAntifraudeService;
	
	private Combobox cmbEmpresaPtoVtaAntifraude;
	private Textbox txtChaveAntifraude;
	private PtovtaAntifraude ptovtaAntifraude;
	private List<Empresa> lsEmpresas;
	private PuntoVenta puntoVenta;
	private MyListbox ptovtaAntifraudeList;
	private Empresa empresa;
	
	@Override
	public void doAfterCompose(Component comp) throws Exception {
		
		super.doAfterCompose(comp);
		ptovtaAntifraude = (PtovtaAntifraude) Executions.getCurrent().getArg().get("ptovtaComissao");
		this.puntoVenta = (PuntoVenta) Executions.getCurrent().getArg().get("puntoVenta");
		this.ptovtaAntifraudeList = (MyListbox) Executions.getCurrent().getArg().get("ptovtaAntifraudeList");
		lsEmpresas = UsuarioLogado.getUsuarioLogado().getEmpresa();
		empresa = ptovtaAntifraude.getEmpresa();
		txtChaveAntifraude.setValue(ptovtaAntifraude.getChave());
		
	}

	public void onClick$btnSalvarPtovtaAntifraude(Event ev) throws InterruptedException {
		try {
			if(verificarCamposAddChaveAntifraude()) {
				if (cmbEmpresaPtoVtaAntifraude.getSelectedItem() == null) {
					return;
				}
				txtChaveAntifraude.getValue();
				
				ptovtaAntifraude.setEmpresa(getEmpresa());
				ptovtaAntifraude.setChave(txtChaveAntifraude.getValue());
				ptovtaAntifraude.setUsuarioId(UsuarioLogado.getUsuarioLogado().getUsuarioId());
				ptovtaAntifraude = ptovtaAntifraudeService.actualizacion(ptovtaAntifraude);
				puntoVenta.getPtovtaAntifraudes().set(puntoVenta.getPtovtaAntifraudes().indexOf(ptovtaAntifraude), ptovtaAntifraude);
				ptovtaAntifraudeList.setData(puntoVenta.getPtovtaAntifraudes());
				closeWindow();
			}
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}

	}

	public List<Empresa> getLsEmpresas() {
		return lsEmpresas;
	}
	
	private boolean verificarCamposAddChaveAntifraude() throws InterruptedException {
		if (cmbEmpresaPtoVtaAntifraude.getSelectedItem() == null) {
			Messagebox.show(
					Labels.getLabel("editarPuntoVentaController.MSG.empresaAntifraudeNaoInformada"),
					Labels.getLabel("editarPuntoVentaController.window.title"),
					Messagebox.OK, Messagebox.EXCLAMATION);
			return false;
		}
		
		txtChaveAntifraude.getValue();
		if(StringUtils.isBlank(txtChaveAntifraude.getValue())) {
			Messagebox.show(
					Labels.getLabel("editarPuntoVentaController.MSG.chaveAntifraudeNaoInformada"),
					Labels.getLabel("editarPuntoVentaController.window.title"),
					Messagebox.OK, Messagebox.EXCLAMATION);
			return false;
		}
		
		if(ptovtaAntifraudeList.getListData() != null) {
			Empresa empresa = (Empresa) cmbEmpresaPtoVtaAntifraude.getSelectedItem().getValue();
			for (Object obj : ptovtaAntifraudeList.getListData()) {
				PtovtaAntifraude ptovtaAntifraude = (PtovtaAntifraude) obj;
				if(empresa.equals(ptovtaAntifraude.getEmpresa()) && !ptovtaAntifraude.equals(this.ptovtaAntifraude)) {
					Messagebox.show(
							Labels.getLabel("editarPuntoVentaController.MSG.empresaAntifraudeJaCadastrada"),
							Labels.getLabel("editarPuntoVentaController.window.title"),
							Messagebox.OK, Messagebox.EXCLAMATION);					
					return false;
				}
			}
		}
		return true;
	}

	public Empresa getEmpresa() {
		return empresa;
	}

	public void setEmpresa(Empresa empresa) {
		this.empresa = empresa;
	}

}

==> 1.152.0.tar.gz: admmono/src/java/com/rjconsultores/ventaboletos/web/gui/controladores/catalogos/EditarPtovtaAntifraudeController.java <==
package com.rjconsultores.ventaboletos.web.gui.controladores.catalogos;

import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.Executions;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zul.Combobox;
import org.zkoss.zul.Messagebox;
import org.zkoss.zul.Textbox;

import com.rjconsultores.ventaboletos.entidad.Empresa;
import com.rjconsultores.ventaboletos.entidad.PtovtaAntifraude;
import com.rjconsultores.ventaboletos.entidad.PuntoVenta;
import com.rjconsultores.ventaboletos.service.PtovtaAntifraudeService;
import com.rjconsultores.ventaboletos.utilerias.UsuarioLogado;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;
import com.rjconsultores.ventaboletos.web.utilerias.MyListbox;

/**
 * 
 * @author wilian
 * 
 */
@Controller("editarPtovtaAntifraudeController")
@Scope("prototype")
public class EditarPtovtaAntifraudeController extends MyGenericForwardComposer {
	
	private static final long serialVersionUID = 1L;

	private static Logger log = LogManager.getLogger(EditarPtovtaAntifraudeController.class);
	
	@Autowired
	private PtovtaAntifraudeService ptovtaAntifraudeService;
	
	private Combobox cmbEmpresaPtoVtaAntifraude;
	private Textbox txtChaveAntifraude;
	private PtovtaAntifraude ptovtaAntifraude;
	private List<Empresa> lsEmpresas;
	private PuntoVenta puntoVenta;
	private MyListbox ptovtaAntifraudeList;
	private Empresa empresa;
	
	@Override
	public void doAfterCompose(Component comp) throws Exception {
		
		super.doAfterCompose(comp);
		ptovtaAntifraude = (PtovtaAntifraude) Executions.getCurrent().getArg().get("ptovtaComissao");
		this.puntoVenta = (PuntoVenta) Executions.getCurrent().getArg().get("puntoVenta");
		this.ptovtaAntifraudeList = (MyListbox) Executions.getCurrent().getArg().get("ptovtaAntifraudeList");
		lsEmpresas = UsuarioLogado.getUsuarioLogado().getEmpresa();
		empresa = ptovtaAntifraude.getEmpresa();
		txtChaveAntifraude.setValue(ptovtaAntifraude.getChave());
		
	}

	public void onClick$btnSalvarPtovtaAntifraude(Event ev) throws InterruptedException {
		try {
			if(verificarCamposAddChaveAntifraude()) {
				if (cmbEmpresaPtoVtaAntifraude.getSelectedItem() == null) {
					return;
				}
				txtChaveAntifraude.getValue();
				
				ptovtaAntifraude.setEmpresa(getEmpresa());
				ptovtaAntifraude.setChave(txtChaveAntifraude.getValue());
				ptovtaAntifraude.setUsuarioId(UsuarioLogado.getUsuarioLogado().getUsuarioId());
				ptovtaAntifraude = ptovtaAntifraudeService.actualizacion(ptovtaAntifraude);
				puntoVenta.getPtovtaAntifraudes().set(puntoVenta.getPtovtaAntifraudes().indexOf(ptovtaAntifraude), ptovtaAntifraude);
				ptovtaAntifraudeList.setData(puntoVenta.getPtovtaAntifraudes());
				closeWindow();
			}
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}

	}

	public List<Empresa> getLsEmpresas() {
		return lsEmpresas;
	}
	
	private boolean verificarCamposAddChaveAntifraude() throws InterruptedException {
		if (cmbEmpresaPtoVtaAntifraude.getSelectedItem() == null) {
			Messagebox.show(
					Labels.getLabel("editarPuntoVentaController.MSG.empresaAntifraudeNaoInformada"),
					Labels.getLabel("editarPuntoVentaController.window.title"),
					Messagebox.OK, Messagebox.EXCLAMATION);
			return false;
		}
		
		txtChaveAntifraude.getValue();
		if(StringUtils.isBlank(txtChaveAntifraude.getValue())) {
			Messagebox.show(
					Labels.getLabel("editarPuntoVentaController.MSG.chaveAntifraudeNaoInformada"),
					Labels.getLabel("editarPuntoVentaController.window.title"),
					Messagebox.OK, Messagebox.EXCLAMATION);
			return false;
		}
		
		if(ptovtaAntifraudeList.getListData() != null) {
			Empresa empresa = (Empresa) cmbEmpresaPtoVtaAntifraude.getSelectedItem().getValue();
			for (Object obj : ptovtaAntifraudeList.getListData()) {
				PtovtaAntifraude ptovtaAntifraude = (PtovtaAntifraude) obj;
				if(empresa.equals(ptovtaAntifraude.getEmpresa()) && !ptovtaAntifraude.equals(this.ptovtaAntifraude)) {
					Messagebox.show(
							Labels.getLabel("editarPuntoVentaController.MSG.empresaAntifraudeJaCadastrada"),
							Labels.getLabel("editarPuntoVentaController.window.title"),
							Messagebox.OK, Messagebox.EXCLAMATION);					
					return false;
				}
			}
		}
		return true;
	}

	public Empresa getEmpresa() {
		return empresa;
	}

	public void setEmpresa(Empresa empresa) {
		this.empresa = empresa;
	}

}
